Index: daily-build
===================================================================
--- daily-build	(revision 43198)
+++ daily-build	(working copy)
@@ -32,11 +32,22 @@
 	# Default to keeping 30 days of builds. Set to zero to keep all.
 	NUM_KEEP=30
 fi
+
 # Overridable environment variables for building.
 if [ -z "$ROOTCMD" ]; then
 	ROOTCMD="fakeroot"
 fi
 
+# Internal environment variables to keep file attributes between targets
+# when fakeroot is used.
+# As we start with an empty file, we can use -i also on first invocation.
+ROOTCMDOPTS=""
+if [ "$ROOTCMD" = fakeroot ]; then
+	FRSAVE="$(mktemp -t d-i_daily-build.XXXXXX)"
+	trap 'rm -f $FRSAVE' 0 HUP INT QUIT TERM
+	ROOTCMDOPTS="-i $FRSAVE -s $FRSAVE"
+fi
+
 overview () {
 	LANG=C echo "$(dpkg --print-architecture) ($(date)) $(whoami)@$(hostname | cut -d . -f 1) $1" >> dest/overview.log
 }
@@ -52,15 +63,17 @@
 
 	# Override $TARGETS with custom makefile targets.
 	if [ -z "$TARGETS" ]; then
-		TARGETS="$($ROOTCMD make all_list |grep '^build')"
+		TARGETS="$($ROOTCMD make all_list | grep '^build')"
 	fi
 
 	$ROOTCMD make reallyclean > /dev/null
 	mkdir dest
 	touch dest/overview.log
+
+	# Save file attributes within this loop if fakeroot is used
 	for t in $TARGETS; do
 		header BUILDING IMAGE FOR $t > dest/$t.log
-		if $ROOTCMD make $t >> dest/$t.log 2>&1; then
+		if $ROOTCMD $ROOTCMDOPTS make $t >> dest/$t.log 2>&1; then
 			overview "$t success"
 		else
 			overview "$t failed"
